@@ -2,26 +2,26 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_users.pl,v 1.52 2005/06/27 10:35:14 yeupou Exp $
+# $Id: sv_users.pl,v 1.54 2005/07/01 10:25:46 zerodeux Exp $
 #
 #  Copyright 2001-2005 (c) Loic Dachary <loic--gnu.org> (sv_cvs.pl)
 #                          Mathieu Roy <yeupou--gnu.org> 
 #                          Sylvain Beucler <beuc--beuc.net>
 #                          Timothee Besset <ttimo--ttimo.net>
 #
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 ##
 ## This script should be used via a cronjob to update the system
@@ -453,7 +453,7 @@ foreach my $user (@only_in_db){
 	    system("/bin/chmod", "2755", $home);
 	    system("/bin/chmod", "755", "$home/.ssh", "$home/.gnupg");
 	    system("/bin/chmod", "600", "$home/.ssh/authorized_keys");
-	    system("/bin/chown", "-R", "$user.$svusers", $home);
+	    system("/bin/chown", "-R", "$user:$svusers", $home);
 	    
 	}
 	# Increment the uid for the next user, avoid the special value 
