@@ -2,23 +2,23 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sendmail.php,v 1.19 2005/06/20 15:00:59 yeupou Exp $
+# $Id: sendmail.php,v 1.23 2005/08/31 21:05:09 yeupou Exp $
 #
 #  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 # Every mails sent should be using functions listed here.
 
@@ -67,7 +67,7 @@ function sendmail_mail ($from,
   # Write the add. headers 
   # Note: RFC-821 recommends to use \r\n as line break in headers but \n
   # works and there are report of failures with \r\n so we let \n for now.
-  $more_headers = "From: ".$from."\n";
+  $more_headers = "From: ".sendmail_encode_header_content($from)."\n";
   if ($reply_to)
     { $more_headers .= "Reply-To: ".$reply_to."\n"; }
   $more_headers .= "X-Savane-Server: ".$GLOBALS['SERVER_NAME'].":".$GLOBALS['SERVER_PORT']." [".$GLOBALS['SERVER_ADDR']."]\n";
@@ -168,7 +168,9 @@ function sendmail_mail ($from,
     # If $v is set, add it to the list, 
     # unless user want a specific subject line
     if (!$skip)
-      { $real_to .= $v.", "; }
+      { 
+	$real_to .= $v.", "; 
+      }
 
     } 
 
@@ -192,19 +194,19 @@ function sendmail_mail ($from,
    # report has been posted to the Mailman team - wait&see [bug #1980]
    $message = str_replace("\r\n", "\n", $message);
 
-   # Send the mail in UTF-8
-   # Fixme: apparently From/To should not contains anything but ascii...
-   #        utf-8 stuff in names will look like garbage.
+   # Send the mail in UTF-8.
+   # Normally, nothing non-ASCII should be contained in To: field, apart the 
+   # real names.
    if ($real_to) 
 	{
-	  $ret .= mail($real_to, sendmail_encode_header_content($subject), $message, $more_headers);
+	  $ret .= mail(sendmail_encode_header_content($real_to), sendmail_encode_header_content($subject), $message, $more_headers);
 	  fb(sprintf(_("Mail sent to %s"), utils_antispam_email($real_to)));
 	} 
    
    # Send mails with specific subject line
    while (list(,$v) = each($list)) 
      {
-        $ret .= mail($user_name[$v], sendmail_encode_header_content($user_subject[$v]), $message, $more_headers);
+        $ret .= mail(sendmail_encode_header_content($user_name[$v]), sendmail_encode_header_content($user_subject[$v]), $message, $more_headers);
 	fb(sprintf(_("Mail sent to %s"), utils_antispam_email($user_name[$v])));
      }  
       
@@ -213,11 +215,46 @@ function sendmail_mail ($from,
 
 
 # Needed to send utf-8 headers:
+# Take a look at http://www.faqs.org/rfcs/rfc2047.html
+# We should use mb_encode_mimeheader() but it just does not work.
+#
+# We must not encode starting and ending quotes.
+# We assume there could be only 2 quotes. Otherwise it would be a malformed
+# address.
+# The easy way we use to do this is to simply consider as one string the 
+# content of the quote, if any. If so, we are not working word per word but
+# it saves us the time of searching for quotes in every words.
 function sendmail_encode_header_content ($header, $charset="UTF-8")
 {
-  # Take a look at http://www.faqs.org/rfcs/rfc2047.html
-  # We should use mb_encode_mimeheader() but it just does not work.
-  return "=?UTF-8?B?".base64_encode($header)."?=";
+  if (ereg('"', $header)) 
+   {
+     # quotes found, we each quoted part will be a string to encode
+     $words = split('"', $header);
+     $withquotes = 1;
+   }
+  else 
+   {
+     # otherwise, the default behavior is to consider words as strings to 
+     # encode
+     $words = split(' ', $header);
+   }
+
+  while (list($key,$word) = each($words))
+    {
+      # Check word per word if they need encoding
+      if (!utils_is_ascii($word)) {
+         $words[$key] = "=?$charset?B?".base64_encode($word)."?=";
+      }
+    }
+  
+  if ($withquotes) 
+   {
+     return join('"', $words);
+   }
+  else
+   {
+     return join(' ', $words);
+   }
 }
 
 
