@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: data.php,v 1.27 2005/05/29 10:20:51 toddy Exp $
+# $Id: data.php,v 1.29 2005/08/31 21:05:09 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -11,19 +11,19 @@
 #                          Yves Perrin <yves.perrin--cern.ch>
 #
 #
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 
 /*
@@ -1121,7 +1121,6 @@ function trackers_data_update_value ($item_fv_id,$field,$group_id,$value,$descri
   if (db_affected_rows($result) < 1)
     {
       fb(_("Update of field value failed."));
-      ' - '.db_error();
     }
   else
     {
@@ -1197,7 +1196,6 @@ function trackers_data_update_usage($field_name,
   $result = db_query($sql);
   $rows = db_numrows($result);
 
-  fb($sql.$rows);
   # if it does exist then update it else insert a new usage entry for this field.
   if ($rows)
     {
@@ -1456,6 +1454,9 @@ function trackers_data_handle_update ($group_id,
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_handle_update ';
 
+  # variable to track changes made inside the function
+  $change_exists = false;
+
   # Update an item. Rk: vfl is an variable list of fields, Vary from one
   # project to another
   # return true if bug updated, false if nothing changed or
@@ -1658,6 +1659,7 @@ function trackers_data_handle_update ($group_id,
   # are added in the bug history along with the comment type.
   if ($details != '')
     {
+      $change_exists = 1;
       trackers_data_add_history ('details',
 				 htmlspecialchars($details),
 				 '',
@@ -1691,6 +1693,7 @@ function trackers_data_handle_update ($group_id,
 	      trackers_data_update_dependent_items($dep, $item_id, $art);
 
               $changes['Depends on']['add'] = $art." #".$dep;
+              $change_exists = 1;
 
 	      # Check if we're supposed to send all modifications to an address
 	      list($address, $sendall) = trackers_data_get_item_notification_info($dep, $art, 1);
@@ -1708,8 +1711,7 @@ function trackers_data_handle_update ($group_id,
 
   # Finally, build the full SQL query and update the bug itself (if need be)
 
-  $result = true;
- dbg("UPD LIST: $upd_list");
+  dbg("UPD LIST: $upd_list");
   if ($upd_list)
     {
       dbg($upd_list);
@@ -1720,6 +1722,20 @@ function trackers_data_handle_update ($group_id,
 	 " WHERE bug_id='$item_id' AND group_id='$group_id'";
       $result=db_affected_rows(db_query($sql));
     }
+  else
+    {
+      if (!$change_exists) 
+	{
+	  fb(_("No field to update")); 
+          # must return false, otherwise a notif would be sent
+	  return false;
+	}
+      else
+	{
+	  #fb(_("Item Successfully Updated"));
+	  return true;
+	}
+    }
 
   if (!$result)
     {
@@ -1731,6 +1747,7 @@ function trackers_data_handle_update ($group_id,
       fb(_("Item Successfully Updated"));
       return true;
     }
+
 }
 
 function trackers_data_reassign_item ($item_id,
@@ -1985,10 +2002,11 @@ function trackers_data_update_dependent_items ($depends_on, $item_id, $artifact)
       $result=db_query($sql);
       if (!$result)
 	{
-	  fb(_("Error inserting dependancy").db_error(), 0);
+	  fb(_("Error inserting dependancy"), 1);
 	}
       else
 	{
+          fb(_("Dependency added"));
 	  trackers_data_add_history("Dependencies",
 				    "-",
 				    "Depends on ".$artifact." #".$depends_on,
