@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.18 2005/03/22 17:32:31 toddy Exp $
+# $Id: general.php,v 1.21 2005/07/05 15:32:05 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -11,19 +11,19 @@
 #                          Yves Perrin <yves.perrin--cern.ch>
 #
 #
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 
 # Return the file that should be included, according to the URL
@@ -258,7 +258,6 @@ function trackers_field_display ($field_name,
 	      else
 		{ $arr[$i] = trackers_data_get_value($field_name,$group_id,$arr[$i]); }
 	    }
-
 	  $output .= join('<br />', $arr);
 
 	}
@@ -1164,14 +1163,14 @@ function trackers_attach_file($item_id,
   #  - then with strlen after the call the addslashes(): the check must be
   #  made on the final size for import in the database.
   #
-  if (filesize($input_file) > 512000) {
-    fb(_("File not attached: must be > 20 chars and < 512000 chars in length, after escaping characters as required."), 1);
+  if (filesize($input_file) > 524288) {
+    fb(sprintf(_("File not attached: the allowed size is 512 kB, after escaping characters as required. The file you were trying to attach is %s kB large."), filesize($input_file)/1024), 1);
     return false;
   }
   $data = addslashes(fread($data, filesize($input_file)));
-  if ((strlen($data) < 20) || (strlen($data) > 512000))
+  if (strlen($data) > 524288)
     {
-      fb(sprintf(_("File not attached: must be > 20 chars and < 512000 chars in length. After escaping characters as required, it sized %s."), strlen($data)), 1);
+      fb(sprintf(_("File not attached: the allowed size is 512 kB. After escaping characters as required, it sized %s kB."), strlen($data)/1024), 1);
       return false;
     }
 
