@@ -2,26 +2,26 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.57 2005/03/20 16:40:46 yeupou Exp $
+# $Id: index.php,v 1.59 2005/08/31 21:05:08 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #
 #  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Sylvain Beucler <beuc--beuc.net>
 # 
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 require "include/pre.php";
 require_directory("people");
@@ -63,10 +63,6 @@ print '
    <div class="indexright">
 ';
 print show_features_boxes();
-print "\n<br />\n";
-print $HTML->box_top(_("Help Wanted"),'',1);
-print people_show_category_list();
-print $HTML->box_bottom(1);
 print '
    </div><!-- end indexright --> 
 ';
