@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: Version.pm,v 1.8 2005/09/02 22:18:59 yeupou Exp $
+# $Id: Version.pm,v 1.11 2005/09/13 13:51:08 yeupou Exp $
 #
 # Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -32,7 +32,9 @@ our $version = 1;
 
 # Return a configuration item
 sub GetVersion {
-    return "1.0.8";
+    # Should be a valid release number or
+    #     CVS (before x.x)
+    return "1.1";
 }
 
 # EOF
