@@ -1,19 +1,19 @@
 #  Copyright 2004 (c) Yves Perrin <yves.perrin--at--cern.ch>
 #                     Mathieu Roy <yeupou--at--gnu.org>
 #
-# This program is free software; you can redistribute it and/or      
+# The Savane project is free software; you can redistribute it and/or      
 # modify it under the terms of the GNU General Public License    
 # as published by the Free Software Foundation; either version 2   
 # of the License, or (at your option) any later version.          
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of 
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 # GNU General Public License for more details.                        
 #                                                                     
 # You should have received a copy of the GNU General Public License   
-# along with this program; if not, write to the Free Software 
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software 
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 CREATE TABLE trackers_field_transition_other_field_update (
   other_field_update_id int(11) NOT NULL auto_increment,
